SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
Этот коммит содержится в:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
коммит произвёл GitHub
родитель f6f8a0d144
Коммит e6ded45898
14 изменённых файлов: 47 добавлений и 47 удалений
+2 -2
Просмотреть файл
@@ -28,11 +28,11 @@ __device__ float myDeviceGlobal;
__device__ float myDeviceGlobalArray[16];
extern "C" __global__ void hello_world(const float* a, float* b) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
b[tx] = a[tx];
}
extern "C" __global__ void test_globals(const float* a, float* b) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
b[tx] = a[tx] + myDeviceGlobal + myDeviceGlobalArray[tx % ARRAY_SIZE];
}